@@ -39,6 +39,23 @@ RSpec.describe "bundle update" do
     end
   end
 
+  describe "with --verbose" do
+    before do
+      build_repo2
+
+      install_gemfile <<~G
+        source "https://gem.repo2"
+        gem "myrack"
+      G
+    end
+
+    it "logs the reason for re-resolving" do
+      bundle "update --verbose"
+      expect(out).not_to include("Found changes from the lockfile")
+      expect(out).to include("Re-resolving dependencies because bundler is unlocking")
+    end
+  end
+
   describe "with --all" do
     before do
       build_repo2
@@ -755,7 +772,7 @@ RSpec.describe "bundle update" do
       G
     end
 
-    it "should fail loudly", bundler: "< 3" do
+    it "should fail loudly" do
       bundle "install --deployment"
       bundle "update", all: true, raise_on_error: false
 
@@ -1019,7 +1036,7 @@ RSpec.describe "bundle update" do
     end
   end
 
-  context "with multiple, duplicated sources, with lockfile in old format", bundler: "< 3" do
+  context "with multiple, duplicated sources, with lockfile in old format" do
     before do
       build_repo2 do
         build_gem "dotenv", "2.7.6"
@@ -1123,7 +1140,7 @@ RSpec.describe "bundle update in more complicated situations" do
     end
 
     bundle "update thin myrack-obama"
-    expect(last_command.stdboth).to include "Bundler attempted to update myrack-obama but its version stayed the same"
+    expect(stdboth).to include "Bundler attempted to update myrack-obama but its version stayed the same"
     expect(the_bundle).to include_gems "thin 2.0", "myrack 10.0", "myrack-obama 1.0"
   end
 
@@ -1141,7 +1158,7 @@ RSpec.describe "bundle update in more complicated situations" do
 
     bundle "update foo"
 
-    expect(last_command.stdboth).not_to include "attempted to update"
+    expect(stdboth).not_to include "attempted to update"
   end
 
   it "will not warn when changing gem sources but not versions" do
@@ -1159,7 +1176,7 @@ RSpec.describe "bundle update in more complicated situations" do
 
     bundle "update myrack"
 
-    expect(last_command.stdboth).not_to include "attempted to update"
+    expect(stdboth).not_to include "attempted to update"
   end
 
   it "will update only from pinned source" do
@@ -1249,7 +1266,7 @@ RSpec.describe "bundle update in more complicated situations" do
     it "is not updated because it is not actually included in the bundle" do
       simulate_platform "x86_64-linux" do
         bundle "update a"
-        expect(last_command.stdboth).to include "Bundler attempted to update a but it was not considered because it is for a different platform from the current one"
+        expect(stdboth).to include "Bundler attempted to update a but it was not considered because it is for a different platform from the current one"
         expect(the_bundle).to_not include_gem "a"
       end
     end
@@ -1290,7 +1307,7 @@ RSpec.describe "bundle update when a gem depends on a newer version of bundler"
 
   it "should explain that bundler conflicted and how to resolve the conflict" do
     bundle "update", all: true, raise_on_error: false
-    expect(last_command.stdboth).not_to match(/in snapshot/i)
+    expect(stdboth).not_to match(/in snapshot/i)
     expect(err).to match(/current Bundler version/i).
       and match(/Install the necessary version with `gem install bundler:9\.9\.9`/i)
   end
@@ -1527,7 +1544,9 @@ RSpec.describe "bundle update --bundler" do
   end
 
   it "updates the bundler version in the lockfile even if the latest version is not installed", :ruby_repo do
-    pristine_system_gems "bundler-2.99.9"
+    bundle "config path.system true"
+
+    pristine_system_gems "bundler-9.0.0"
 
     build_repo4 do
       build_gem "myrack", "1.0"
@@ -1535,13 +1554,16 @@ RSpec.describe "bundle update --bundler" do
       build_bundler "999.0.0"
     end
 
+    checksums = checksums_section do |c|
+      c.checksum(gem_repo4, "myrack", "1.0")
+    end
+
     install_gemfile <<-G
       source "https://gem.repo4"
       gem "myrack"
     G
-    lockfile lockfile.sub(/(^\s*)#{Bundler::VERSION}($)/, "2.99.9")
 
-    bundle :update, bundler: true, verbose: true, preserve_ruby_flags: true
+    bundle :update, bundler: true, verbose: true
 
     expect(out).to include("Updating bundler to 999.0.0")
     expect(out).to include("Running `bundle update --bundler \"> 0.a\" --verbose` with bundler 999.0.0")
@@ -1558,7 +1580,7 @@ RSpec.describe "bundle update --bundler" do
 
       DEPENDENCIES
         myrack
-
+      #{checksums}
       BUNDLED WITH
          999.0.0
     L
@@ -1667,8 +1689,8 @@ RSpec.describe "bundle update --bundler" do
     expect(err).to eq("The `bundle update --bundler` target version (999.999.999) does not exist")
   end
 
-  it "allows updating to development versions if already installed locally" do
-    system_gems "bundler-2.3.0.dev"
+  it "errors if the explicit target version does not exist, even if auto switching is disabled" do
+    pristine_system_gems "bundler-9.9.9"
 
     build_repo4 do
       build_gem "myrack", "1.0"
@@ -1679,7 +1701,26 @@ RSpec.describe "bundle update --bundler" do
       gem "myrack"
     G
 
-    bundle :update, bundler: "2.3.0.dev", verbose: "true"
+    bundle :update, bundler: "999.999.999", raise_on_error: false, env: { "BUNDLER_VERSION" => "9.9.9" }
+
+    expect(last_command).to be_failure
+    expect(err).to eq("The `bundle update --bundler` target version (999.999.999) does not exist")
+  end
+
+  it "allows updating to development versions if already installed locally" do
+    system_gems "bundler-9.9.9"
+
+    build_repo4 do
+      build_gem "myrack", "1.0"
+    end
+
+    install_gemfile <<-G
+      source "https://gem.repo4"
+      gem "myrack"
+    G
+
+    system_gems "bundler-9.0.0.dev", path: local_gem_path
+    bundle :update, bundler: "9.0.0.dev", verbose: "true"
 
     checksums = checksums_section_when_enabled do |c|
       c.checksum(gem_repo4, "myrack", "1.0")
@@ -1698,14 +1739,14 @@ RSpec.describe "bundle update --bundler" do
           myrack
         #{checksums}
         BUNDLED WITH
-           2.3.0.dev
+           9.0.0.dev
       L
 
-    expect(out).to include("Using bundler 2.3.0.dev")
+    expect(out).to include("Using bundler 9.0.0.dev")
   end
 
   it "does not touch the network if not necessary" do
-    system_gems "bundler-2.3.9"
+    system_gems "bundler-9.9.9"
 
     build_repo4 do
       build_gem "myrack", "1.0"
@@ -1715,8 +1756,8 @@ RSpec.describe "bundle update --bundler" do
       source "https://gem.repo4"
       gem "myrack"
     G
-
-    bundle :update, bundler: "2.3.9", verbose: true
+    system_gems "bundler-9.0.0", path: local_gem_path
+    bundle :update, bundler: "9.0.0", verbose: true
 
     expect(out).not_to include("Fetching gem metadata from https://rubygems.org/")
 
@@ -1738,14 +1779,14 @@ RSpec.describe "bundle update --bundler" do
           myrack
         #{checksums}
         BUNDLED WITH
-           2.3.9
+           9.0.0
       L
 
-    expect(out).to include("Using bundler 2.3.9")
+    expect(out).to include("Using bundler 9.0.0")
   end
 
   it "prints an error when trying to update bundler in frozen mode" do
-    system_gems "bundler-2.3.9"
+    system_gems "bundler-9.0.0"
 
     gemfile <<~G
       source "https://gem.repo2"
@@ -1762,10 +1803,12 @@ RSpec.describe "bundle update --bundler" do
       DEPENDENCIES
 
       BUNDLED WITH
-         2.1.4
+         9.0.0
     L
 
-    bundle "update --bundler=2.3.9", env: { "BUNDLE_FROZEN" => "true" }, raise_on_error: false
+    system_gems "bundler-9.9.9", path: local_gem_path
+
+    bundle "update --bundler=9.9.9", env: { "BUNDLE_FROZEN" => "true" }, raise_on_error: false
     expect(err).to include("An update to the version of bundler itself was requested, but the lockfile can't be updated because frozen mode is set")
   end
 end
