@@ -8,7 +8,7 @@ RSpec.describe "install in deployment or frozen mode" do
     G
   end
 
-  context "with CLI flags", bundler: "< 3" do
+  context "with CLI flags" do
     it "fails without a lockfile and says that --deployment requires a lock" do
       bundle "install --deployment", raise_on_error: false
       expect(err).to include("The --deployment flag requires a lockfile")
@@ -321,7 +321,7 @@ RSpec.describe "install in deployment or frozen mode" do
       L
 
       bundle :install, env: { "BUNDLE_FROZEN" => "true" }, raise_on_error: false, artifice: "compact_index"
-      expect(err).to include("Your lock file is missing \"bar\", but the lockfile can't be updated because frozen mode is set")
+      expect(err).to include("Your lockfile is missing \"bar\", but can't be updated because frozen mode is set")
     end
 
     it "explodes if a path gem is missing" do
@@ -550,7 +550,7 @@ RSpec.describe "install in deployment or frozen mode" do
       pristine_system_gems :bundler
       bundle "config set --local deployment true"
       bundle "install --verbose"
-      expect(out).not_to include("but the lockfile can't be updated because frozen mode is set")
+      expect(out).not_to include("can't be updated because frozen mode is set")
       expect(out).not_to include("You have added to the Gemfile")
       expect(out).not_to include("You have deleted from the Gemfile")
       expect(out).to include("vendor/cache/foo")
