@@ -1,6 +1,6 @@
 # frozen_string_literal: true
 
-RSpec.shared_examples "bundle install --standalone" do
+RSpec.describe "bundle install --standalone" do
   shared_examples "common functionality" do
     it "still makes the gems available to normal bundler" do
       args = expected_gems.map {|k, v| "#{k} #{v}" }
@@ -8,9 +8,9 @@ RSpec.shared_examples "bundle install --standalone" do
     end
 
     it "still makes system gems unavailable to normal bundler" do
-      system_gems "rack-1.0.0"
+      system_gems "myrack-1.0.0"
 
-      expect(the_bundle).to_not include_gems("rack")
+      expect(the_bundle).to_not include_gems("myrack")
     end
 
     it "generates a bundle/bundler/setup.rb" do
@@ -63,14 +63,14 @@ RSpec.shared_examples "bundle install --standalone" do
     end
 
     it "makes system gems unavailable without bundler" do
-      system_gems "rack-1.0.0"
+      system_gems "myrack-1.0.0"
 
       testrb = String.new <<-RUBY
         $:.unshift File.expand_path("bundle")
         require "bundler/setup"
 
         begin
-          require "rack"
+          require "myrack"
         rescue LoadError
           puts "LoadError"
         end
@@ -97,7 +97,7 @@ RSpec.shared_examples "bundle install --standalone" do
         testrb << "\nrequire \"#{k}\""
         testrb << "\nputs #{k.upcase}"
       end
-      ruby testrb, :dir => "#{bundled_app}2"
+      ruby testrb, dir: "#{bundled_app}2"
 
       expect(out).to eq(expected_gems.values.join("\n"))
     end
@@ -122,11 +122,11 @@ RSpec.shared_examples "bundle install --standalone" do
   describe "with simple gems" do
     before do
       gemfile <<-G
-        source "#{file_uri_for(gem_repo1)}"
+        source "https://gem.repo1"
         gem "rails"
       G
       bundle "config set --local path #{bundled_app("bundle")}"
-      bundle :install, :standalone => true, :dir => cwd
+      bundle :install, standalone: true, dir: cwd
     end
 
     let(:expected_gems) do
@@ -140,22 +140,14 @@ RSpec.shared_examples "bundle install --standalone" do
   end
 
   describe "with default gems and a lockfile", :ruby_repo do
-    before do
-      skip "does not work on rubygems versions where `--install_dir` doesn't respect --default" unless Gem::Installer.for_spec(loaded_gemspec, :install_dir => "/foo").default_spec_file == "/foo/specifications/default/bundler-#{Bundler::VERSION}.gemspec" # Since rubygems 3.2.0.rc.2
-      skip "does not work on old rubies because the realworld gems that need to be installed don't support them" if RUBY_VERSION < "2.7.0"
+    it "works and points to the vendored copies, not to the default copies" do
+      base_system_gems "stringio", "psych", "etc", path: scoped_gem_path(bundled_app("bundle"))
 
-      realworld_system_gems "tsort --version 0.1.0"
-
-      necessary_system_gems = ["optparse --version 0.1.1", "psych --version 3.3.2", "logger --version 1.4.3", "etc --version 1.2.0", "stringio --version 3.0.1"]
-      necessary_system_gems += ["shellwords --version 0.1.0", "base64 --version 0.1.0", "resolv --version 0.2.1"] if Gem.rubygems_version < Gem::Version.new("3.3.a")
-      necessary_system_gems += ["yaml --version 0.1.1"] if Gem.rubygems_version < Gem::Version.new("3.4.a")
-      realworld_system_gems(*necessary_system_gems, :path => scoped_gem_path(bundled_app("bundle")))
-
-      build_gem "foo", "1.0.0", :to_system => true, :default => true do |s|
+      build_gem "foo", "1.0.0", to_system: true, default: true do |s|
         s.add_dependency "bar"
       end
 
-      build_gem "bar", "1.0.0", :to_system => true, :default => true
+      build_gem "bar", "1.0.0", to_system: true, default: true
 
       build_repo4 do
         build_gem "foo", "1.0.0" do |s|
@@ -170,12 +162,11 @@ RSpec.shared_examples "bundle install --standalone" do
         gem "foo"
       G
 
-      bundle "lock", :dir => cwd, :artifice => "compact_index"
-    end
+      bundle "lock", dir: cwd
 
-    it "works and points to the vendored copies, not to the default copies", :realworld do
       bundle "config set --local path #{bundled_app("bundle")}"
-      bundle :install, :standalone => true, :dir => cwd, :artifice => "compact_index", :env => { "BUNDLER_GEM_DEFAULT_DIR" => system_gem_path.to_s }
+
+      bundle :install, standalone: true, dir: cwd, env: { "BUNDLER_GEM_DEFAULT_DIR" => system_gem_path.to_s }
 
       load_path_lines = bundled_app("bundle/bundler/setup.rb").read.split("\n").select {|line| line.start_with?("$:.unshift") }
 
@@ -184,27 +175,57 @@ RSpec.shared_examples "bundle install --standalone" do
         '$:.unshift File.expand_path("#{__dir__}/../#{RUBY_ENGINE}/#{Gem.ruby_api_version}/gems/foo-1.0.0/lib")',
       ]
     end
+
+    it "works for gems with extensions and points to the vendored copies, not to the default copies" do
+      simulate_platform "arm64-darwin-23" do
+        base_system_gems "stringio", "psych", "etc", "shellwords", "open3", path: scoped_gem_path(bundled_app("bundle"))
+
+        build_gem "baz", "1.0.0", to_system: true, default: true, &:add_c_extension
+
+        build_repo4 do
+          build_gem "baz", "1.0.0", &:add_c_extension
+        end
+
+        gemfile <<-G
+          source "https://gem.repo4"
+          gem "baz"
+        G
+
+        bundle "config set --local path #{bundled_app("bundle")}"
+
+        bundle "lock", dir: cwd
+
+        bundle :install, standalone: true, dir: cwd, env: { "BUNDLER_GEM_DEFAULT_DIR" => system_gem_path.to_s }
+      end
+
+      load_path_lines = bundled_app("bundle/bundler/setup.rb").read.split("\n").select {|line| line.start_with?("$:.unshift") }
+
+      expect(load_path_lines).to eq [
+        '$:.unshift File.expand_path("#{__dir__}/../#{RUBY_ENGINE}/#{Gem.ruby_api_version}/extensions/arm64-darwin-23/#{Gem.extension_api_version}/baz-1.0.0")',
+        '$:.unshift File.expand_path("#{__dir__}/../#{RUBY_ENGINE}/#{Gem.ruby_api_version}/gems/baz-1.0.0/lib")',
+      ]
+    end
   end
 
   describe "with Gemfiles using absolute path sources and resulting bundle moved to a folder hierarchy with different nesting" do
     before do
-      build_lib "minitest", "1.0.0", :path => lib_path("minitest")
+      build_lib "minitest", "1.0.0", path: lib_path("minitest")
 
       Dir.mkdir bundled_app("app")
 
       gemfile bundled_app("app/Gemfile"), <<-G
-        source "#{file_uri_for(gem_repo1)}"
+        source "https://gem.repo1"
         gem "minitest", :path => "#{lib_path("minitest")}"
       G
 
-      bundle "install", :standalone => true, :dir => bundled_app("app")
+      bundle "install", standalone: true, dir: bundled_app("app")
 
       Dir.mkdir tmp("one_more_level")
       FileUtils.mv bundled_app, tmp("one_more_level")
     end
 
     it "also works" do
-      ruby <<-RUBY, :dir => tmp("one_more_level/bundled_app/app")
+      ruby <<-RUBY, dir: tmp("one_more_level/bundled_app/app")
         require "./bundle/bundler/setup"
 
         require "minitest"
@@ -216,24 +237,26 @@ RSpec.shared_examples "bundle install --standalone" do
     end
   end
 
+  let(:cwd) { bundled_app }
+
   describe "with Gemfiles using relative path sources and app moved to a different root" do
     before do
       FileUtils.mkdir_p bundled_app("app/vendor")
 
-      build_lib "minitest", "1.0.0", :path => bundled_app("app/vendor/minitest")
+      build_lib "minitest", "1.0.0", path: bundled_app("app/vendor/minitest")
 
       gemfile bundled_app("app/Gemfile"), <<-G
-        source "#{file_uri_for(gem_repo1)}"
+        source "https://gem.repo1"
         gem "minitest", :path => "vendor/minitest"
       G
 
-      bundle "install", :standalone => true, :dir => bundled_app("app")
+      bundle "install", standalone: true, dir: bundled_app("app")
 
       FileUtils.mv(bundled_app("app"), bundled_app2("app"))
     end
 
     it "also works" do
-      ruby <<-RUBY, :dir => bundled_app2("app")
+      ruby <<-RUBY, dir: bundled_app2("app")
         require "./bundle/bundler/setup"
 
         require "minitest"
@@ -248,8 +271,8 @@ RSpec.shared_examples "bundle install --standalone" do
   describe "with gems with native extension" do
     before do
       bundle "config set --local path #{bundled_app("bundle")}"
-      install_gemfile <<-G, :standalone => true, :dir => cwd
-        source "#{file_uri_for(gem_repo1)}"
+      install_gemfile <<-G, standalone: true, dir: cwd
+        source "https://gem.repo1"
         gem "very_simple_binary"
       G
     end
@@ -268,7 +291,7 @@ RSpec.shared_examples "bundle install --standalone" do
 
   describe "with gem that has an invalid gemspec" do
     before do
-      build_git "bar", :gemspec => false do |s|
+      build_git "bar", gemspec: false do |s|
         s.write "lib/bar/version.rb", %(BAR_VERSION = '1.0')
         s.write "bar.gemspec", <<-G
           lib = File.expand_path('lib/', __dir__)
@@ -286,15 +309,15 @@ RSpec.shared_examples "bundle install --standalone" do
         G
       end
       bundle "config set --local path #{bundled_app("bundle")}"
-      install_gemfile <<-G, :standalone => true, :dir => cwd, :raise_on_error => false
-        source "#{file_uri_for(gem_repo1)}"
+      install_gemfile <<-G, standalone: true, dir: cwd, raise_on_error: false
+        source "https://gem.repo1"
         gem "bar", :git => "#{lib_path("bar-1.0")}"
       G
     end
 
     it "outputs a helpful error message" do
       expect(err).to include("You have one or more invalid gemspecs that need to be fixed.")
-      expect(err).to include("bar 1.0 has an invalid gemspec")
+      expect(err).to include("bar.gemspec is not valid")
     end
   end
 
@@ -303,12 +326,12 @@ RSpec.shared_examples "bundle install --standalone" do
       build_git "devise", "1.0"
 
       gemfile <<-G
-        source "#{file_uri_for(gem_repo1)}"
+        source "https://gem.repo1"
         gem "rails"
         gem "devise", :git => "#{lib_path("devise-1.0")}"
       G
       bundle "config set --local path #{bundled_app("bundle")}"
-      bundle :install, :standalone => true, :dir => cwd
+      bundle :install, standalone: true, dir: cwd
     end
 
     let(:expected_gems) do
@@ -327,16 +350,16 @@ RSpec.shared_examples "bundle install --standalone" do
       build_git "devise", "1.0"
 
       gemfile <<-G
-        source "#{file_uri_for(gem_repo1)}"
+        source "https://gem.repo1"
         gem "rails"
 
         group :test do
           gem "rspec"
-          gem "rack-test"
+          gem "myrack-test"
         end
       G
       bundle "config set --local path #{bundled_app("bundle")}"
-      bundle :install, :standalone => true, :dir => cwd
+      bundle :install, standalone: true, dir: cwd
     end
 
     let(:expected_gems) do
@@ -350,7 +373,7 @@ RSpec.shared_examples "bundle install --standalone" do
 
     it "allows creating a standalone file with limited groups" do
       bundle "config set --local path #{bundled_app("bundle")}"
-      bundle :install, :standalone => "default", :dir => cwd
+      bundle :install, standalone: "default", dir: cwd
 
       load_error_ruby <<-RUBY, "spec"
         $:.unshift File.expand_path("bundle")
@@ -368,7 +391,7 @@ RSpec.shared_examples "bundle install --standalone" do
     it "allows `without` configuration to limit the groups used in a standalone" do
       bundle "config set --local path #{bundled_app("bundle")}"
       bundle "config set --local without test"
-      bundle :install, :standalone => true, :dir => cwd
+      bundle :install, standalone: true, dir: cwd
 
       load_error_ruby <<-RUBY, "spec"
         $:.unshift File.expand_path("bundle")
@@ -385,7 +408,7 @@ RSpec.shared_examples "bundle install --standalone" do
 
     it "allows `path` configuration to change the location of the standalone bundle" do
       bundle "config set --local path path/to/bundle"
-      bundle "install", :standalone => true, :dir => cwd
+      bundle "install", standalone: true, dir: cwd
 
       ruby <<-RUBY
         $:.unshift File.expand_path("path/to/bundle")
@@ -400,9 +423,9 @@ RSpec.shared_examples "bundle install --standalone" do
 
     it "allows `without` to limit the groups used in a standalone" do
       bundle "config set --local without test"
-      bundle :install, :dir => cwd
+      bundle :install, dir: cwd
       bundle "config set --local path #{bundled_app("bundle")}"
-      bundle :install, :standalone => true, :dir => cwd
+      bundle :install, standalone: true, dir: cwd
 
       load_error_ruby <<-RUBY, "spec"
         $:.unshift File.expand_path("bundle")
@@ -428,7 +451,7 @@ RSpec.shared_examples "bundle install --standalone" do
           gem "rails"
         G
         bundle "config set --local path #{bundled_app("bundle")}"
-        bundle :install, :standalone => true, :artifice => "endpoint", :dir => cwd
+        bundle :install, standalone: true, artifice: "endpoint", dir: cwd
       end
 
       let(:expected_gems) do
@@ -442,14 +465,14 @@ RSpec.shared_examples "bundle install --standalone" do
     end
   end
 
-  describe "with --binstubs", :bundler => "< 3" do
+  describe "with --binstubs" do
     before do
       gemfile <<-G
-        source "#{file_uri_for(gem_repo1)}"
+        source "https://gem.repo1"
         gem "rails"
       G
       bundle "config set --local path #{bundled_app("bundle")}"
-      bundle :install, :standalone => true, :binstubs => true, :dir => cwd
+      bundle :install, standalone: true, binstubs: true, dir: cwd
     end
 
     let(:expected_gems) do
@@ -467,7 +490,7 @@ RSpec.shared_examples "bundle install --standalone" do
 
     it "creates stubs that can be executed from anywhere" do
       require "tmpdir"
-      sys_exec(%(#{bundled_app("bin/rails")} -v), :dir => Dir.tmpdir)
+      sys_exec(%(#{bundled_app("bin/rails")} -v), dir: Dir.tmpdir)
       expect(out).to eq("2.3.2")
     end
 
@@ -490,38 +513,55 @@ RSpec.shared_examples "bundle install --standalone" do
   end
 end
 
-RSpec.describe "bundle install --standalone" do
-  let(:cwd) { bundled_app }
-
-  include_examples("bundle install --standalone")
-end
-
 RSpec.describe "bundle install --standalone run in a subdirectory" do
   let(:cwd) { bundled_app("bob").tap(&:mkpath) }
 
-  include_examples("bundle install --standalone")
+  before do
+    gemfile <<-G
+      source "https://gem.repo1"
+      gem "rails"
+    G
+  end
+
+  it "generates the script in the proper place" do
+    bundle :install, standalone: true, dir: cwd
+
+    expect(bundled_app("bundle/bundler/setup.rb")).to exist
+  end
+
+  context "when path set to a relative path" do
+    before do
+      bundle "config set --local path bundle"
+    end
+
+    it "generates the script in the proper place" do
+      bundle :install, standalone: true, dir: cwd
+
+      expect(bundled_app("bundle/bundler/setup.rb")).to exist
+    end
+  end
 end
 
 RSpec.describe "bundle install --standalone --local" do
   before do
     gemfile <<-G
-      source "#{file_uri_for(gem_repo1)}"
-      gem "rack"
+      source "https://gem.repo1"
+      gem "myrack"
     G
 
-    system_gems "rack-1.0.0", :path => default_bundle_path
+    system_gems "myrack-1.0.0", path: default_bundle_path
   end
 
   it "generates script pointing to system gems" do
     bundle "install --standalone --local --verbose"
 
-    expect(out).to include("Using rack 1.0.0")
+    expect(out).to include("Using myrack 1.0.0")
 
     load_error_ruby <<-RUBY, "spec"
       require "./bundler/setup"
 
-      require "rack"
-      puts RACK
+      require "myrack"
+      puts MYRACK
       require "spec"
     RUBY
 
