@@ -28,14 +28,14 @@ RSpec.describe "bundle install" do
     end
 
     it "displays the correct default branch", git: ">= 2.28.0" do
-      build_git "foo", "1.0", path: lib_path("foo"), default_branch: "main"
+      build_git "foo", "1.0", path: lib_path("foo"), default_branch: "non-standard"
 
       install_gemfile <<-G, verbose: true
         source "https://gem.repo1"
         gem "foo", :git => "#{lib_path("foo")}"
       G
 
-      expect(out).to include("Using foo 1.0 from #{lib_path("foo")} (at main@#{revision_for(lib_path("foo"))[0..6]})")
+      expect(out).to include("Using foo 1.0 from #{lib_path("foo")} (at non-standard@#{revision_for(lib_path("foo"))[0..6]})")
       expect(the_bundle).to include_gems "foo 1.0", source: "git@#{lib_path("foo")}"
     end
 
