@@ -48,11 +48,11 @@ RSpec.describe "Resolving platform craziness" do
   it "takes the latest ruby gem, even if an older platform specific version is available" do
     @index = build_index do
       gem "foo", "1.0.0"
-      gem "foo", "1.0.0", "x64-mingw32"
+      gem "foo", "1.0.0", "x64-mingw-ucrt"
       gem "foo", "1.1.0"
     end
     dep "foo"
-    platforms "x64-mingw32"
+    platforms "x64-mingw-ucrt"
 
     should_resolve_as %w[foo-1.1.0]
   end
@@ -61,12 +61,12 @@ RSpec.describe "Resolving platform craziness" do
     @index = build_index do
       gem "bar", "1.0.0"
       gem "foo", "1.0.0"
-      gem "foo", "1.0.0", "x64-mingw32" do
+      gem "foo", "1.0.0", "x64-mingw-ucrt" do
         dep "bar", "< 1"
       end
     end
     dep "foo"
-    platforms "x64-mingw32"
+    platforms "x64-mingw-ucrt"
 
     should_resolve_as %w[foo-1.0.0]
   end
@@ -74,15 +74,15 @@ RSpec.describe "Resolving platform craziness" do
   it "prefers the platform specific gem to the ruby version" do
     @index = build_index do
       gem "foo", "1.0.0"
-      gem "foo", "1.0.0", "x64-mingw32"
+      gem "foo", "1.0.0", "x64-mingw-ucrt"
     end
     dep "foo"
-    platforms "x64-mingw32"
+    platforms "x64-mingw-ucrt"
 
-    should_resolve_as %w[foo-1.0.0-x64-mingw32]
+    should_resolve_as %w[foo-1.0.0-x64-mingw-ucrt]
   end
 
-  describe "on a linux platform", :rubygems => ">= 3.1.0.pre.1" do
+  describe "on a linux platform" do
     # Ruby's platform is *-linux => platform's libc is glibc, so not musl
     # Ruby's platform is *-linux-musl => platform's libc is musl, so not glibc
     # Gem's platform is *-linux => gem is glibc + maybe musl compatible
@@ -159,15 +159,15 @@ RSpec.describe "Resolving platform craziness" do
     before do
       @index = build_index do
         gem "foo", "1.0.0"
-        gem "foo", "1.0.0", "x64-mingw32"
+        gem "foo", "1.0.0", "x64-mingw-ucrt"
         gem "foo", "1.1.0"
-        gem "foo", "1.1.0", "x64-mingw32" do |s|
+        gem "foo", "1.1.0", "x64-mingw-ucrt" do |s|
           s.required_ruby_version = [">= 2.0", "< 2.4"]
         end
         gem "Ruby\0", "2.5.1"
       end
       dep "Ruby\0", "2.5.1"
-      platforms "x64-mingw32"
+      platforms "x64-mingw-ucrt"
     end
 
     it "takes the latest ruby gem" do
@@ -186,18 +186,18 @@ RSpec.describe "Resolving platform craziness" do
   it "takes the latest ruby gem with required_ruby_version if the platform specific gem doesn't match the required_ruby_version" do
     @index = build_index do
       gem "foo", "1.0.0"
-      gem "foo", "1.0.0", "x64-mingw32"
+      gem "foo", "1.0.0", "x64-mingw-ucrt"
       gem "foo", "1.1.0" do |s|
         s.required_ruby_version = [">= 2.0"]
       end
-      gem "foo", "1.1.0", "x64-mingw32" do |s|
+      gem "foo", "1.1.0", "x64-mingw-ucrt" do |s|
         s.required_ruby_version = [">= 2.0", "< 2.4"]
       end
       gem "Ruby\0", "2.5.1"
     end
     dep "foo"
     dep "Ruby\0", "2.5.1"
-    platforms "x64-mingw32"
+    platforms "x64-mingw-ucrt"
 
     should_resolve_as %w[foo-1.1.0]
   end
@@ -205,18 +205,18 @@ RSpec.describe "Resolving platform craziness" do
   it "takes the latest ruby gem if the platform specific gem doesn't match the required_ruby_version with multiple platforms" do
     @index = build_index do
       gem "foo", "1.0.0"
-      gem "foo", "1.0.0", "x64-mingw32"
+      gem "foo", "1.0.0", "x64-mingw-ucrt"
       gem "foo", "1.1.0" do |s|
         s.required_ruby_version = [">= 2.0"]
       end
-      gem "foo", "1.1.0", "x64-mingw32" do |s|
+      gem "foo", "1.1.0", "x64-mingw-ucrt" do |s|
         s.required_ruby_version = [">= 2.0", "< 2.4"]
       end
       gem "Ruby\0", "2.5.1"
     end
     dep "foo"
     dep "Ruby\0", "2.5.1"
-    platforms "x86_64-linux", "x64-mingw32"
+    platforms "x86_64-linux", "x64-mingw-ucrt"
 
     should_resolve_as %w[foo-1.1.0]
   end
@@ -342,7 +342,7 @@ RSpec.describe "Resolving platform craziness" do
   describe "with mingw32" do
     before :each do
       @index = build_index do
-        platforms "mingw32 mswin32 x64-mingw32 x64-mingw-ucrt" do |platform|
+        platforms "mingw32 mswin32 x64-mingw-ucrt" do |platform|
           gem "thin", "1.2.7", platform
         end
         gem "win32-api", "1.5.1", "universal-mingw32"
@@ -363,10 +363,10 @@ RSpec.describe "Resolving platform craziness" do
       should_resolve_as %w[thin-1.2.7-mingw32]
     end
 
-    it "finds x64-mingw32 gems" do
-      platforms "x64-mingw32"
+    it "finds x64-mingw-ucrt gems" do
+      platforms "x64-mingw-ucrt"
       dep "thin"
-      should_resolve_as %w[thin-1.2.7-x64-mingw32]
+      should_resolve_as %w[thin-1.2.7-x64-mingw-ucrt]
     end
 
     it "finds universal-mingw gems on x86-mingw" do
@@ -376,25 +376,21 @@ RSpec.describe "Resolving platform craziness" do
     end
 
     it "finds universal-mingw gems on x64-mingw" do
-      platform "x64-mingw32"
+      platform "x64-mingw-ucrt"
       dep "win32-api"
       should_resolve_as %w[win32-api-1.5.1-universal-mingw32]
     end
 
-    if Gem.rubygems_version >= Gem::Version.new("3.2.28")
-      it "finds x64-mingw-ucrt gems" do
-        platforms "x64-mingw-ucrt"
-        dep "thin"
-        should_resolve_as %w[thin-1.2.7-x64-mingw-ucrt]
-      end
+    it "finds x64-mingw-ucrt gems" do
+      platforms "x64-mingw-ucrt"
+      dep "thin"
+      should_resolve_as %w[thin-1.2.7-x64-mingw-ucrt]
     end
 
-    if Gem.rubygems_version >= Gem::Version.new("3.3.18")
-      it "finds universal-mingw gems on x64-mingw-ucrt" do
-        platform "x64-mingw-ucrt"
-        dep "win32-api"
-        should_resolve_as %w[win32-api-1.5.1-universal-mingw32]
-      end
+    it "finds universal-mingw gems on x64-mingw-ucrt", rubygems: ">= 3.3.18" do
+      platform "x64-mingw-ucrt"
+      dep "win32-api"
+      should_resolve_as %w[win32-api-1.5.1-universal-mingw32]
     end
   end
 
