@@ -8,22 +8,21 @@ module Spec
     include Spec::Path
     include Spec::Helpers
 
-    def write_build_metadata(dir: source_root)
+    def write_build_metadata(dir: source_root, version: Bundler::VERSION)
       build_metadata = {
-        :git_commit_sha => git_commit_sha,
-        :built_at => loaded_gemspec.date.utc.strftime("%Y-%m-%d"),
-        :release => true,
+        git_commit_sha: git_commit_sha,
+        built_at: release_date_for(version, dir: dir),
       }
 
-      replace_build_metadata(build_metadata, dir: dir) # rubocop:disable Style/HashSyntax
+      replace_build_metadata(build_metadata, dir: dir)
     end
 
     def reset_build_metadata(dir: source_root)
       build_metadata = {
-        :release => false,
+        built_at: nil,
       }
 
-      replace_build_metadata(build_metadata, dir: dir) # rubocop:disable Style/HashSyntax
+      replace_build_metadata(build_metadata, dir: dir)
     end
 
     private
@@ -41,7 +40,12 @@ module Spec
     end
 
     def git_commit_sha
-      ruby_core_tarball? ? "unknown" : sys_exec("git rev-parse --short HEAD", :dir => source_root).strip
+      ruby_core_tarball? ? "unknown" : git("rev-parse --short HEAD", source_root).strip
+    end
+
+    def release_date_for(version, dir:)
+      changelog = File.expand_path("CHANGELOG.md", dir)
+      File.readlines(changelog)[2].scan(/^## #{Regexp.escape(version)} \((.*)\)/).first&.first if File.exist?(changelog)
     end
 
     extend self
