@@ -1,11 +1,11 @@
 # frozen_string_literal: true
 
 class RequirementChecker < Proc
-  def self.against(present)
-    provided = Gem::Version.new(present)
-
+  def self.against(provided)
     new do |required|
-      !Gem::Requirement.new(required).satisfied_by?(provided)
+      requirement = Gem::Requirement.new(required)
+
+      !requirement.satisfied_by?(provided)
     end.tap do |checker|
       checker.provided = provided
     end
@@ -21,8 +21,7 @@ end
 RSpec.configure do |config|
   config.filter_run_excluding realworld: true
 
-  config.filter_run_excluding bundler: RequirementChecker.against(Bundler::VERSION.split(".")[0])
-  config.filter_run_excluding rubygems: RequirementChecker.against(Gem::VERSION)
+  config.filter_run_excluding rubygems: RequirementChecker.against(Gem.rubygems_version)
   config.filter_run_excluding ruby_repo: !ENV["GEM_COMMAND"].nil?
   config.filter_run_excluding no_color_tty: Gem.win_platform? || !ENV["GITHUB_ACTION"].nil?
   config.filter_run_excluding permissions: Gem.win_platform?
@@ -32,4 +31,8 @@ RSpec.configure do |config|
   config.filter_run_excluding man: Gem.win_platform?
 
   config.filter_run_when_matching :focus unless ENV["CI"]
+
+  config.before(:each, bundler: "4") do
+    bundle "config simulate_version 4"
+  end
 end
