@@ -25,12 +25,8 @@ module Spec
       @relative_gemspec ||= ruby_core? ? "lib/bundler/bundler.gemspec" : "bundler.gemspec"
     end
 
-    def gemspec_dir
-      @gemspec_dir ||= gemspec.parent
-    end
-
     def loaded_gemspec
-      @loaded_gemspec ||= Gem::Specification.load(gemspec.to_s)
+      @loaded_gemspec ||= Dir.chdir(source_root) { Gem::Specification.load(gemspec.to_s) }
     end
 
     def test_gemfile
@@ -49,8 +45,16 @@ module Spec
       @dev_gemfile ||= tool_dir.join("dev_gems.rb")
     end
 
+    def dev_binstub
+      @dev_binstub ||= bindir.join("bundle")
+    end
+
     def bindir
-      @bindir ||= source_root.join(ruby_core? ? "libexec" : "exe")
+      @bindir ||= source_root.join(ruby_core? ? "spec/bin" : "bin")
+    end
+
+    def exedir
+      @exedir ||= source_root.join(ruby_core? ? "libexec" : "exe")
     end
 
     def installed_bindir
@@ -67,7 +71,7 @@ module Spec
 
     def path
       env_path = ENV["PATH"]
-      env_path = env_path.split(File::PATH_SEPARATOR).reject {|path| path == bindir.to_s }.join(File::PATH_SEPARATOR) if ruby_core?
+      env_path = env_path.split(File::PATH_SEPARATOR).reject {|path| path == exedir.to_s }.join(File::PATH_SEPARATOR) if ruby_core?
       env_path
     end
 
@@ -79,6 +83,10 @@ module Spec
       @man_dir ||= lib_dir.join("bundler/man")
     end
 
+    def hax
+      @hax ||= spec_dir.join("support/hax.rb")
+    end
+
     def tracked_files
       @tracked_files ||= git_ls_files(tracked_files_glob)
     end
@@ -102,18 +110,18 @@ module Spec
     end
 
     def tmp(*path)
-      tmp_root(scope).join(*path)
+      tmp_root.join("#{test_env_version}.#{scope}").join(*path)
     end
 
-    def tmp_root(scope)
-      source_root.join("tmp", "#{test_env_version}.#{scope}")
+    def tmp_root
+      source_root.join("tmp")
     end
 
     # Bump this version whenever you make a breaking change to the spec setup
     # that requires regenerating tmp/.
 
     def test_env_version
-      1
+      2
     end
 
     def scope
@@ -128,7 +136,7 @@ module Spec
     end
 
     def default_bundle_path(*path)
-      if Bundler.feature_flag.default_install_uses_path?
+      if Bundler.feature_flag.bundler_4_mode?
         local_gem_path(*path)
       else
         system_gem_path(*path)
@@ -143,6 +151,10 @@ module Spec
       end
     end
 
+    def compact_index_cache_path
+      home(".bundle/cache/compact_index")
+    end
+
     def bundled_app(*path)
       root = tmp("bundled_app")
       FileUtils.mkdir_p(root)
@@ -171,20 +183,20 @@ module Spec
       bundled_app("Gemfile.lock")
     end
 
+    def scoped_base_system_gem_path
+      scoped_gem_path(base_system_gem_path)
+    end
+
     def base_system_gem_path
-      scoped_gem_path(base_system_gems)
+      tmp_root.join("gems/base")
     end
 
-    def base_system_gems
-      tmp("gems/base")
+    def rubocop_gem_path
+      tmp_root.join("gems/rubocop")
     end
 
-    def rubocop_gems
-      tmp("gems/rubocop")
-    end
-
-    def standard_gems
-      tmp("gems/standard")
+    def standard_gem_path
+      tmp_root.join("gems/standard")
     end
 
     def file_uri_for(path)
@@ -195,35 +207,35 @@ module Spec
     end
 
     def gem_repo1(*args)
-      tmp("gems/remote1", *args)
+      gem_path("remote1", *args)
     end
 
     def gem_repo_missing(*args)
-      tmp("gems/missing", *args)
+      gem_path("missing", *args)
     end
 
     def gem_repo2(*args)
-      tmp("gems/remote2", *args)
+      gem_path("remote2", *args)
     end
 
     def gem_repo3(*args)
-      tmp("gems/remote3", *args)
+      gem_path("remote3", *args)
     end
 
     def gem_repo4(*args)
-      tmp("gems/remote4", *args)
+      gem_path("remote4", *args)
     end
 
     def security_repo(*args)
-      tmp("gems/security_repo", *args)
+      gem_path("security_repo", *args)
     end
 
     def system_gem_path(*path)
-      tmp("gems/system", *path)
+      gem_path("system", *path)
     end
 
     def pristine_system_gem_path
-      tmp("gems/base_system")
+      tmp_root.join("gems/pristine_system")
     end
 
     def local_gem_path(*path, base: bundled_app)
@@ -234,6 +246,10 @@ module Spec
       base.join(Gem.ruby_engine, RbConfig::CONFIG["ruby_version"])
     end
 
+    def gem_path(*args)
+      tmp("gems", *args)
+    end
+
     def lib_path(*args)
       tmp("libs", *args)
     end
@@ -261,7 +277,7 @@ module Spec
     def replace_version_file(version, dir: source_root)
       version_file = File.expand_path("lib/bundler/version.rb", dir)
       contents = File.read(version_file)
-      contents.sub!(/(^\s+VERSION\s*=\s*)"#{Gem::Version::VERSION_PATTERN}"/, %(\\1"#{version}"))
+      contents.sub!(/(^\s+VERSION\s*=\s*).*$/, %(\\1"#{version}"))
       File.open(version_file, "w") {|f| f << contents }
     end
 
@@ -272,12 +288,23 @@ module Spec
       File.open(gemspec_file, "w") {|f| f << contents }
     end
 
+    def replace_changelog(version, dir:)
+      changelog = File.expand_path("CHANGELOG.md", dir)
+      contents = File.readlines(changelog)
+      contents = [contents[0], contents[1], "## #{version} (2100-01-01)\n", *contents[3..-1]].join
+      File.open(changelog, "w") {|f| f << contents }
+    end
+
     def git_root
       ruby_core? ? source_root : source_root.parent
     end
 
     def rake_path
-      Dir["#{base_system_gems}/#{Bundler.ruby_scope}/**/rake*.gem"].first
+      find_base_path("rake")
+    end
+
+    def rake_version
+      File.basename(rake_path).delete_prefix("rake-").delete_suffix(".gem")
     end
 
     def sinatra_dependency_paths
@@ -289,12 +316,17 @@ module Spec
         ruby2_keywords
         base64
         logger
+        cgi
       ]
-      Dir[base_system_gem_path.join("gems/{#{deps.join(",")}}-*/lib")].map(&:to_s)
+      Dir[scoped_base_system_gem_path.join("gems/{#{deps.join(",")}}-*/lib")].map(&:to_s)
     end
 
     private
 
+    def find_base_path(name)
+      Dir["#{scoped_base_system_gem_path}/**/#{name}-*.gem"].first
+    end
+
     def git_ls_files(glob)
       skip "Not running on a git context, since running tests from a tarball" if ruby_core_tarball?
 
