@@ -1002,7 +1002,7 @@ class Gem::Specification < Gem::BasicSpecification
   def self.find_in_unresolved_tree(path)
     unresolved_specs.each do |spec|
       spec.traverse do |_from_spec, _dep, to_spec, trail|
-        if to_spec.has_conflicts? || to_spec.conficts_when_loaded_with?(trail)
+        if to_spec.has_conflicts? || to_spec.conflicts_when_loaded_with?(trail)
           :next
         else
           return trail.reverse if to_spec.contains_requirable_file? path
@@ -1415,13 +1415,11 @@ class Gem::Specification < Gem::BasicSpecification
         raise e
       end
 
-      begin
-        specs = spec_dep.to_specs.uniq(&:full_name)
-      rescue Gem::MissingSpecError => e
-        raise Gem::MissingSpecError.new(e.name, e.requirement, "at: #{spec_file}")
-      end
+      specs = spec_dep.matching_specs(true).uniq(&:full_name)
 
-      if specs.size == 1
+      if specs.size == 0
+        raise Gem::MissingSpecError.new(spec_dep.name, spec_dep.requirement, "at: #{spec_file}")
+      elsif specs.size == 1
         specs.first.activate
       else
         name = spec_dep.name
@@ -1651,7 +1649,7 @@ class Gem::Specification < Gem::BasicSpecification
   ##
   # return true if there will be conflict when spec if loaded together with the list of specs.
 
-  def conficts_when_loaded_with?(list_of_specs) # :nodoc:
+  def conflicts_when_loaded_with?(list_of_specs) # :nodoc:
     result = list_of_specs.any? do |spec|
       spec.runtime_dependencies.any? {|dep| (dep.name == name) && !satisfies_requirement?(dep) }
     end
@@ -2146,11 +2144,11 @@ class Gem::Specification < Gem::BasicSpecification
       @files.concat(@extra_rdoc_files)
     end
 
-    @files            = @files.uniq if @files
-    @extensions       = @extensions.uniq if @extensions
-    @test_files       = @test_files.uniq if @test_files
-    @executables      = @executables.uniq if @executables
-    @extra_rdoc_files = @extra_rdoc_files.uniq if @extra_rdoc_files
+    @files            = @files.uniq.sort if @files
+    @extensions       = @extensions.uniq.sort if @extensions
+    @test_files       = @test_files.uniq.sort if @test_files
+    @executables      = @executables.uniq.sort if @executables
+    @extra_rdoc_files = @extra_rdoc_files.uniq.sort if @extra_rdoc_files
   end
 
   ##
