@@ -4,7 +4,7 @@ require_relative "helper"
 require "rubygems/command_manager"
 
 class TestGemCommandManager < Gem::TestCase
-  PROJECT_DIR = File.expand_path("../..", __dir__).tap(&Gem::UNTAINT)
+  PROJECT_DIR = File.expand_path("../..", __dir__)
 
   def setup
     super
@@ -43,23 +43,24 @@ class TestGemCommandManager < Gem::TestCase
     assert_kind_of Gem::Commands::SigninCommand, command
   end
 
-  def test_find_logout_alias_comamnd
+  def test_find_logout_alias_command
     command = @command_manager.find_command "logout"
 
     assert_kind_of Gem::Commands::SignoutCommand, command
   end
 
   def test_find_command_ambiguous_exact
-    ins_command = Class.new
-    Gem::Commands.send :const_set, :InsCommand, ins_command
+    old_load_path = $:.dup
+    $: << File.expand_path("test/rubygems", PROJECT_DIR)
 
     @command_manager.register_command :ins
 
     command = @command_manager.find_command "ins"
 
-    assert_kind_of ins_command, command
+    assert_kind_of Gem::Commands::InsCommand, command
   ensure
-    Gem::Commands.send :remove_const, :InsCommand
+    $:.replace old_load_path
+    @command_manager.unregister_command :ins
   end
 
   def test_find_command_unknown
@@ -150,7 +151,7 @@ class TestGemCommandManager < Gem::TestCase
       end
     end
 
-    assert_match(/install isn't a directory./i, @ui.error)
+    assert_match(/install isn't a directory\./i, @ui.error)
   end
 
   def test_process_args_with_c_flag_path_not_found
@@ -164,7 +165,7 @@ class TestGemCommandManager < Gem::TestCase
       end
     end
 
-    assert_match(/#{custom_start_point} isn't a directory./i, @ui.error)
+    assert_match(/#{Regexp.quote(custom_start_point)} isn't a directory\./i, @ui.error)
   end
 
   def test_process_args_bad_arg
@@ -179,7 +180,7 @@ class TestGemCommandManager < Gem::TestCase
 
   # HACK: move to install command test
   def test_process_args_install
-    #capture all install options
+    # capture all install options
     use_ui @ui do
       check_options = nil
       @command_manager["install"].when_invoked do |options|
@@ -187,7 +188,7 @@ class TestGemCommandManager < Gem::TestCase
         true
       end
 
-      #check defaults
+      # check defaults
       @command_manager.process_args %w[install]
       assert_equal %w[ri], check_options[:document].sort
       assert_equal false, check_options[:force]
@@ -197,7 +198,7 @@ class TestGemCommandManager < Gem::TestCase
       assert_nil   check_options[:install_dir]
       assert_nil   check_options[:bin_dir]
 
-      #check settings
+      # check settings
       check_options = nil
       @command_manager.process_args %w[
         install --force --local --document=ri,rdoc --install-dir .
@@ -211,17 +212,17 @@ class TestGemCommandManager < Gem::TestCase
       assert_equal Dir.pwd, check_options[:install_dir]
       assert_equal Dir.pwd, check_options[:bin_dir]
 
-      #check remote domain
+      # check remote domain
       check_options = nil
       @command_manager.process_args %w[install --remote]
       assert_equal :remote, check_options[:domain]
 
-      #check both domain
+      # check both domain
       check_options = nil
       @command_manager.process_args %w[install --both]
       assert_equal :both, check_options[:domain]
 
-      #check both domain
+      # check both domain
       check_options = nil
       @command_manager.process_args %w[install --both]
       assert_equal :both, check_options[:domain]
@@ -230,18 +231,18 @@ class TestGemCommandManager < Gem::TestCase
 
   # HACK: move to uninstall command test
   def test_process_args_uninstall
-    #capture all uninstall options
+    # capture all uninstall options
     check_options = nil
     @command_manager["uninstall"].when_invoked do |options|
       check_options = options
       true
     end
 
-    #check defaults
+    # check defaults
     @command_manager.process_args %w[uninstall]
     assert_equal Gem::Requirement.default, check_options[:version]
 
-    #check settings
+    # check settings
     check_options = nil
     @command_manager.process_args %w[uninstall foobar --version 3.0]
     assert_equal "foobar", check_options[:args].first
@@ -250,18 +251,18 @@ class TestGemCommandManager < Gem::TestCase
 
   # HACK: move to check command test
   def test_process_args_check
-    #capture all check options
+    # capture all check options
     check_options = nil
     @command_manager["check"].when_invoked do |options|
       check_options = options
       true
     end
 
-    #check defaults
+    # check defaults
     @command_manager.process_args %w[check]
     assert_equal true, check_options[:alien]
 
-    #check settings
+    # check settings
     check_options = nil
     @command_manager.process_args %w[check foobar --alien]
     assert_equal true, check_options[:alien]
@@ -269,18 +270,18 @@ class TestGemCommandManager < Gem::TestCase
 
   # HACK: move to build command test
   def test_process_args_build
-    #capture all build options
+    # capture all build options
     check_options = nil
     @command_manager["build"].when_invoked do |options|
       check_options = options
       true
     end
 
-    #check defaults
+    # check defaults
     @command_manager.process_args %w[build]
-    #NOTE: Currently no defaults
+    # NOTE: Currently no defaults
 
-    #check settings
+    # check settings
     check_options = nil
     @command_manager.process_args %w[build foobar.rb]
     assert_equal "foobar.rb", check_options[:args].first
@@ -288,14 +289,14 @@ class TestGemCommandManager < Gem::TestCase
 
   # HACK: move to query command test
   def test_process_args_query
-    #capture all query options
+    # capture all query options
     check_options = nil
     @command_manager["query"].when_invoked do |options|
       check_options = options
       true
     end
 
-    #check defaults
+    # check defaults
     Gem::Deprecate.skip_during do
       @command_manager.process_args %w[query]
     end
@@ -303,7 +304,7 @@ class TestGemCommandManager < Gem::TestCase
     assert_equal :local, check_options[:domain]
     assert_equal false, check_options[:details]
 
-    #check settings
+    # check settings
     check_options = nil
     Gem::Deprecate.skip_during do
       @command_manager.process_args %w[query --name foobar --local --details]
@@ -312,14 +313,14 @@ class TestGemCommandManager < Gem::TestCase
     assert_equal :local, check_options[:domain]
     assert_equal true, check_options[:details]
 
-    #remote domain
+    # remote domain
     check_options = nil
     Gem::Deprecate.skip_during do
       @command_manager.process_args %w[query --remote]
     end
     assert_equal :remote, check_options[:domain]
 
-    #both (local/remote) domains
+    # both (local/remote) domains
     check_options = nil
     Gem::Deprecate.skip_during do
       @command_manager.process_args %w[query --both]
@@ -329,18 +330,18 @@ class TestGemCommandManager < Gem::TestCase
 
   # HACK: move to update command test
   def test_process_args_update
-    #capture all update options
+    # capture all update options
     check_options = nil
     @command_manager["update"].when_invoked do |options|
       check_options = options
       true
     end
 
-    #check defaults
+    # check defaults
     @command_manager.process_args %w[update]
     assert_includes check_options[:document], "ri"
 
-    #check settings
+    # check settings
     check_options = nil
     @command_manager.process_args %w[update --force --document=ri --install-dir .]
     assert_includes check_options[:document], "ri"
@@ -368,7 +369,7 @@ class TestGemCommandManager < Gem::TestCase
     end
 
     assert_equal "pew pew!\n", @ui.output
-    assert_match(/WARNING:  foo command is deprecated. It will be removed in Rubygems [0-9]+/, @ui.error)
+    assert_match(/WARNING:  foo command is deprecated\. It will be removed in Rubygems [0-9]+/, @ui.error)
   ensure
     Gem::Commands.send(:remove_const, :FooCommand)
   end
@@ -393,7 +394,7 @@ class TestGemCommandManager < Gem::TestCase
     end
 
     assert_equal "pew pew!\n", @ui.output
-    assert_match(/WARNING:  foo command is deprecated. It will be removed in Rubygems 9.9.9/, @ui.error)
+    assert_match(/WARNING:  foo command is deprecated\. It will be removed in Rubygems 9\.9\.9/, @ui.error)
   ensure
     Gem::Commands.send(:remove_const, :FooCommand)
   end
